@@ -1,6 +1,6 @@
 /*!  \file 
 
-$Id: gdisp_utils.c,v 1.5 2004/10/22 20:17:34 esteban Exp $
+$Id: gdisp_utils.c,v 1.7 2005/02/19 21:35:20 esteban Exp $
 
 -----------------------------------------------------------------------
 
@@ -711,8 +711,8 @@ gdisp_positionIsInsideZone ( PlotSystemZone_T *zone,
       j=0;
     }
 
-    if (zone->pszY[i] < y && zone->pszY[j] >= y ||
-	zone->pszY[j] < y && zone->pszY[i] >= y    ) {
+    if ((zone->pszY[i] < y && zone->pszY[j] >= y) ||
+	(zone->pszY[j] < y && zone->pszY[i] >= y)    ) {
 
       if (zone->pszX[i] + (y - zone->pszY[i]) /
 	  (zone->pszY[j] - zone->pszY[i]) *
@@ -729,3 +729,42 @@ gdisp_positionIsInsideZone ( PlotSystemZone_T *zone,
   return isInside;
 
 }
+
+
+/*
+ * Loop over all elements of the list.
+ * Each element is a TSP symbol the 'sReference' parameter of
+ * which must be decremented.
+ */
+void
+gdisp_dereferenceSymbolList ( GList *symbolList )
+{
+
+  GList    *symbolItem =    (GList*)NULL;
+  Symbol_T *symbol     = (Symbol_T*)NULL;
+
+  /*
+   * Loop over all elements of the list.
+   * Do not forget to decrement the 'sReference' of each symbol.
+   */
+  if (symbolList != (GList*)NULL) {
+
+    symbolItem = g_list_first(symbolList);
+
+    while (symbolItem != (GList*)NULL) {
+
+      symbol = (Symbol_T*)symbolItem->data;
+
+      symbol->sReference--;
+
+      symbolItem = g_list_next(symbolItem);
+
+    }
+
+    g_list_free(symbolList);
+
+  }
+
+}
+
+
