@@ -1,6 +1,6 @@
 /*!  \file 
 
-$Header: /cvsroot/tsp/tsp/src/core/include/tsp_abs_types.h,v 1.16 2004/10/23 13:25:16 deweerdt Exp $
+$Header: /cvsroot/tsp/tsp/src/core/include/tsp_abs_types.h,v 1.19 2005/02/23 19:43:40 erk Exp $
 
 -----------------------------------------------------------------------
 
@@ -38,6 +38,20 @@ Purpose   : Type abstraction : Stolen from GLIB public headers
 #ifndef  __TSP_ABS_TYPES_H
 #define  __TSP_ABS_TYPES_H 1
 
+/* excerpt from libtool manual */
+/* BEGIN_C_DECLS should be used at the beginning of your declarations,
+   so that C++ compilers don't mangle their names.  Use END_C_DECLS at
+   the end of C declarations. */
+#undef BEGIN_C_DECLS
+#undef END_C_DECLS
+#ifdef __cplusplus
+# define BEGIN_C_DECLS extern "C" {
+# define END_C_DECLS }
+#else
+# define BEGIN_C_DECLS /* empty */
+# define END_C_DECLS /* empty */
+#endif
+
 #define TSP_LITTLE_ENDIAN 1234
 #define TSP_BIG_ENDIAN    4321
 #define TSP_PDP_ENDIAN    3412		/* unused, need specific PDP check */	
@@ -105,6 +119,7 @@ Purpose   : Type abstraction : Stolen from GLIB public headers
 /* OSF1 / Alpha */
 #if defined (__osf__) && defined (__alpha)
 # include <inttypes.h>
+typedef int_least16_t int16_t;
 # define TSP_INT64_CONSTANT(val)  (val##L)
 # define TSP_BYTE_ORDER TSP_LITTLE_ENDIAN
 # define TSP_GUINT64_FORMAT "lu"
@@ -130,6 +145,20 @@ Purpose   : Type abstraction : Stolen from GLIB public headers
 #       endif
 #endif /* VXWORKS */
 
+/* FreeBSD : may need testing on non i386 */
+#if defined (__FreeBSD__)
+# define TSP_INT64_CONSTANT(val)  (val##LL)
+#if defined (__sparcv9)
+# define TSP_BYTE_ORDER TSP_BIG_ENDIAN
+#else
+# define TSP_BYTE_ORDER TSP_LITTLE_ENDIAN
+#endif /* Endianness */
+# define TSP_GUINT64_FORMAT "llu"
+# define TSP_SYSTEM_HAVE_NANOSLEEP
+# define TSP_HAVE_INT64 1
+
+#endif /* FreeBSD */
+
 /* OpenBSD / i386 (32 bits) (From Fred&Co) */
 #if defined (__OpenBSD__) &&  defined (__i386__)
 # define TSP_INT64_CONSTANT(val)  (val##LL)
