@@ -1,6 +1,6 @@
 /*!  \file 
 
-$Header: /cvsroot/tsp/tsp/src/util/libbb/bb_core.c,v 1.7 2004/11/02 19:31:30 erk Exp $
+$Header: /cvsroot/tsp/tsp/src/util/libbb/bb_core.c,v 1.12 2005/02/23 17:28:11 dufy Exp $
 
 -----------------------------------------------------------------------
 
@@ -53,6 +53,7 @@ Purpose   : Blackboard Idiom implementation
 #include <bb_core.h>
 #include <bb_utils.h>
 #include "tsp_abs_types.h"
+#include "tsp_sys_headers.h"
 
 /**
  * Convert type to string for display use.
@@ -75,7 +76,7 @@ static const char* E_BB_2STRING[] = {"NoAType 0",
 
 int32_t 
 bb_size(const int32_t n_data, const int32_t data_size) {
-  /* The SHM segment os sized to:
+  /* The SHM segment is sized to:
    *  BB structure size +
    *  data descriptor array size +
    *  data zone size
@@ -243,6 +244,8 @@ bb_value_write(volatile S_BB_T* bb, S_BB_DATADESC_T data_desc,const char* value,
   int hexval;
   assert(bb);
   
+  retval = E_OK;
+
   if ((NULL != strstr(value,"0x")) | 
       (NULL != strstr(value,"0X"))
       ) {
@@ -374,7 +377,7 @@ bb_value_print(volatile S_BB_T* bb, S_BB_DATADESC_T data_desc, FILE* pf, int32_t
       break;	
     case E_BB_CHAR:
       fprintf(pf,"0x%02x<%c> ",((char*) data)[i],
-	      isprint(((char*) data)[i]) ? ((char*) data)[i] : '?');
+	      isprint((int)data[i]) ? ((char*) data)[i] : '?');
       break;
     case E_BB_USER:
       for (j=0; j<data_desc.type_size; ++j) {
@@ -439,9 +442,20 @@ bb_create(S_BB_T** bb,
   }
   if((retcode==E_OK) && (-1==fd_shm)) {
     strncpy(syserr,strerror(errno),MAX_SYSMSG_SIZE);
-    bb_logMsg(BB_LOG_SEVERE,"BlackBoard::bb_create", 
+    /* Try to create an existing segment is NOT an error
+     * its an info that should be handled by the caller.
+     */
+    if (EEXIST!=errno)  {
+
+      bb_logMsg(BB_LOG_SEVERE,"BlackBoard::bb_create", 
 		"Cannot open shm segment <%s key = 0x%x> (%s)",
 		name_shm, bb_utils_ntok(name_shm), syserr);
+    } else {
+      bb_logMsg(BB_LOG_INFO,"BlackBoard::bb_create", 
+		"Cannot open shm segment <%s key = 0x%x> (%s)",
+		name_shm, bb_utils_ntok(name_shm), syserr);
+
+    }
     retcode = E_NOK; 
   }
 
@@ -569,7 +583,7 @@ bb_destroy(S_BB_T** bb) {
   
   /* on se detache de faon a provoquer la destruction */
   if (E_OK == retcode) {
-    if (-1 == shmdt(*bb)) {
+    if (-1 == shmdt((void*)*bb)) {
       strncpy(&syserr[0],strerror(errno),MAX_SYSMSG_SIZE);
       bb_logMsg(BB_LOG_SEVERE,"BlackBoard::bb_destroy", 
 		"SHM detach failed (%s)",syserr);
@@ -586,6 +600,15 @@ bb_destroy(S_BB_T** bb) {
   return retcode;
 } /* end of bb_destroy */
 
+int32_t
+bb_data_memset(S_BB_T* bb, const char c) { 
+  int32_t retcode;  
+  assert(bb);
+  retcode = 0;
+  memset(bb_data(bb),c,bb->max_data_size);
+  return retcode;
+} /* end of bb_data_memset */
+
 int32_t 
 bb_lock(volatile S_BB_T* bb) {
   
@@ -664,11 +687,22 @@ bb_attach(S_BB_T** bb, const char* pc_bb_name) {
     retcode = E_NOK;
   }
   if((E_OK==retcode) && (-1==fd_shm)) {
+
     strncpy(syserr,strerror(errno),MAX_SYSMSG_SIZE);
-    bb_logMsg(BB_LOG_SEVERE,"BlackBoard::bb_attach", 
-	      "Cannot open shm segment <%s key = 0x%x> (%s)",
-	      name_shm, bb_utils_ntok(name_shm), syserr);
-  
+    /* attaching to a non-existing segment is NOT an error
+     * its an info that should be handled by the caller.
+     */
+    if (ENOENT!=errno) {
+
+      bb_logMsg(BB_LOG_SEVERE,"BlackBoard::bb_attach", 
+		"Cannot open shm segment <%s key = 0x%x> (%s)",
+		name_shm, bb_utils_ntok(name_shm), syserr);
+    } else {
+      bb_logMsg(BB_LOG_INFO,"BlackBoard::bb_attach", 
+		"Cannot open shm segment <%s key = 0x%x> (%s)",
+		name_shm, bb_utils_ntok(name_shm), syserr);
+
+    }
     retcode = E_NOK; 
   }
   free(name_shm);
@@ -698,7 +732,7 @@ bb_detach(S_BB_T** bb) {
 /*   bb_logMsg(BB_LOG_INFO,"BlackBoard::bb_detach",  */
 /* 	      "Detachement du BB <%s>.",(*bb)->name); */
 
-  if (-1 == shmdt(*bb)) {
+  if (-1 == shmdt((void*)*bb)) {
     strncpy(&syserr[0],strerror(errno),MAX_SYSMSG_SIZE);
     bb_logMsg(BB_LOG_SEVERE,"BlackBoard::bb_detach", 
 		"SHM detach failed (%s)",syserr);
@@ -714,7 +748,7 @@ void*
 bb_publish(volatile S_BB_T *bb, S_BB_DATADESC_T* data_desc) {
   
   void* retval;
-  int32_t nedeed_size;
+  int32_t needed_size;
 
   retval = NULL;
   assert(bb);
@@ -732,24 +766,24 @@ bb_publish(volatile S_BB_T *bb, S_BB_DATADESC_T* data_desc) {
     bb_lock(bb);
   } else {
     /* calcul de la taille demandee */
-    nedeed_size = data_desc->type_size*data_desc->dimension;    
+    needed_size = data_desc->type_size*data_desc->dimension;    
     /* verification espace disponible dans BB */
     if (bb->n_data >= bb->max_data_desc_size) {
       bb_logMsg(BB_LOG_SEVERE,"BlackBoard::bb_publish", 
 		"No more room in BB data descriptor!! [current n_data=%d]",
 		bb->n_data);
       /* verification taille donnee allouable */
-    } else if ((bb->max_data_size-bb->data_free_offset) < nedeed_size) {
+    } else if ((bb->max_data_size-bb->data_free_offset) < needed_size) {
       bb_logMsg(BB_LOG_SEVERE,"BlackBoard::bb_publish", 
 		"No more room in BB data zone!! [left <%d> byte(s) out of <%d> required]",
-		bb->max_data_size-bb->data_free_offset,nedeed_size);
+		bb->max_data_size-bb->data_free_offset,needed_size);
     } else {     
       /* Calcule de l'adresse libre */
       retval = (char*) bb_data(bb) + bb->data_free_offset;
       /* Mise a jour descripteur en retour */
       data_desc->data_offset = bb->data_free_offset;
       /* Mise a jour prochaine @ libre */
-      bb->data_free_offset  = bb->data_free_offset + nedeed_size;
+      bb->data_free_offset  = bb->data_free_offset + needed_size;
       /* Mise a jour descripteur de donnee */
       bb_data_desc(bb)[bb->n_data] = *data_desc;
       /* On augmente le nombre de donnees */
@@ -938,7 +972,7 @@ bb_snd_msg(volatile S_BB_T *bb,
   assert(bb);
   /* do not flood message queue if no one read it !!*/
   retcode  = msgctl(bb->msgid,IPC_STAT,&mystat);
-  if (!(mystat.__msg_cbytes > 2*MSG_BB_MAX_SIZE)) {
+  if (!(mystat.msg_cbytes > 2*MSG_BB_MAX_SIZE)) {
     /* Non blocking send */
     retcode = msgsnd(bb->msgid,msg,MSG_BB_MAX_SIZE,IPC_NOWAIT);
     if (-1 == retcode) {
@@ -961,7 +995,7 @@ bb_snd_msg(volatile S_BB_T *bb,
     /* NOP */
 /*     bb_logMsg(BB_LOG_WARNING, */
 /* 	      "Blackboard::bb_snd_msg", */
-/* 	      "Cannot send msg <%d> bytes already queued>",mystat.__msg_cbytes); */
+/* 	      "Cannot send msg <%d> bytes already queued>",mystat.msg_cbytes); */
   }
   
   return retcode;
