@@ -1,6 +1,6 @@
 /*!  \file 
 
-$Header: /cvsroot/tsp/tsp/src/util/libbb/bb_core.h,v 1.6 2004/11/12 17:29:47 erk Exp $
+$Header: /cvsroot/tsp/tsp/src/util/libbb/bb_core.h,v 1.8 2005/02/22 20:22:34 erk Exp $
 
 -----------------------------------------------------------------------
 
@@ -37,6 +37,7 @@ Purpose   : BlackBoard Idiom implementation
 #ifndef _BB_H_
 #define _BB_H_
 
+#include <tsp_abs_types.h>
 #include <stdio.h>
 #include <sys/sem.h>
 #if defined(__GNU_LIBRARY__) && !defined(_SEM_SEMUN_UNDEFINED)
@@ -44,6 +45,7 @@ Purpose   : BlackBoard Idiom implementation
 #else
 #ifdef _SEM_SEMUN_UNDEFINED
 #undef _SEM_SEMUN_UNDEFINED
+#endif
 /**
  * Union a definir et utiliser
  * pour les appels 'semop' SysV.
@@ -56,7 +58,6 @@ union semun {
   struct seminfo *__buf;             /* buffer for IPC_INFO */
 };
 #endif
-#endif
 
 
 /**
@@ -198,6 +199,7 @@ typedef struct S_BB {
   int destroyed;
 } S_BB_T;
 
+BEGIN_C_DECLS
 
 /**
  * Return the size of a blackboard with 
@@ -330,6 +332,15 @@ bb_create(S_BB_T** bb,
 int32_t 
 bb_destroy(S_BB_T** bb);
 
+/**
+ * Memset the data area of a BB.
+ * @param  bb INOUT BB pointer, should not be NULL.
+ * @param  c IN, the character used to memset each byte of the 
+ *               BlackBoard data area.
+ */
+int32_t
+bb_data_memset(S_BB_T* bb, const char c);
+
 /**
  * Lock blackboard.
  * A BlackBoard should be locked befaore any structural change
@@ -512,4 +523,6 @@ bb_snd_msg(volatile S_BB_T *bb, S_BB_MSG_T* msg);
  */
 int32_t 
 bb_rcv_msg(volatile S_BB_T *bb, S_BB_MSG_T* msg);
+
+END_C_DECLS
 #endif /* _BB_H_ */
